@@ -192,6 +192,8 @@ class Client():
                         state=None,
                         document_type=None,
                         cpf=None,
+                        start_date=None,
+                        end_date=None,
                         page=None,
                         limit=None):
         json = parse_or_raise(
@@ -200,6 +202,8 @@ class Client():
                                  'state': state,
                                  'type': document_type,
                                  'cpf': cpf,
+                                 'startDate': start_date,
+                                 'endDate': end_date,
                                  'page': page,
                                  'limit': limit
                              }))
@@ -211,6 +215,8 @@ class Client():
                        document_type=None,
                        cpf=None,
                        page=None,
+                       start_date=None,
+                       end_date=None,
                        limit=None):
         '''
         Lista todos os documentos processados pelo RAP Conector, indicando para
@@ -228,6 +234,15 @@ class Client():
         :param cpf: CPF do diplomado, para utilizar como filtro.
         :type cpf: str, optional
 
+        :param start_date: Parâmetro para filtragem, de forma que a resposta só
+            ira conter documentos criados após essa data. Formato da data é o
+            definido em RFC 3339, seção 5.6 (exemplo: ``2021-03-21``).
+        :type start_date: string, optional
+
+        :param end_date: Complementar do ``start_date``. Deve ser fornecido
+            caso ele não seja nulo.
+        :type end_date: string, optional
+
         :param page: Número da página utilizada na paginação dos resultados.
         :type page: int, optional
 
@@ -241,6 +256,8 @@ class Client():
                                     document_type=document_type,
                                     cpf=cpf,
                                     page=page,
+                                    start_date=start_date,
+                                    end_date=end_date,
                                     limit=limit)
 
         return list(
@@ -410,6 +427,8 @@ class ExternalClient(Client):
                        document_type=None,
                        cpf=None,
                        page=None,
+                       start_date=None,
+                       end_date=None,
                        limit=None):
         '''
         Lista todos os documentos processados pelo RAP Conector, indicando para
@@ -427,6 +446,15 @@ class ExternalClient(Client):
         :param cpf: CPF do diplomado, para utilizar como filtro.
         :type cpf: str, optional
 
+        :param start_date: Parâmetro para filtragem, de forma que a resposta só
+            ira conter documentos criados após essa data. Formato da data é o
+            definido em RFC 3339, seção 5.6 (exemplo: ``2021-03-21``).
+        :type start_date: string, optional
+
+        :param end_date: Complementar do ``start_date``. Deve ser fornecido
+            caso ele não seja nulo.
+        :type end_date: string, optional
+
         :param page: Número da página utilizada na paginação dos resultados.
         :type page: int, optional
 
@@ -439,6 +467,8 @@ class ExternalClient(Client):
         docs = self._list_documents(state=state,
                                     document_type=document_type,
                                     cpf=cpf,
+                                    start_date=start_date,
+                                    end_date=end_date,
                                     page=page,
                                     limit=limit)
 
