@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+from json import dumps as json_dumps
+
 from requests_toolbelt import MultipartEncoder
 
 from rapconector.utils import parse_or_raise
@@ -54,6 +56,7 @@ class Document:
                document_type=None,
                document_data=None,
                document_file=None,
+               revocation_data=None,
                update_description=None):
         '''
         Atualiza o dados de um documento, quais sejam: tipo, JSON com dados
@@ -79,6 +82,11 @@ class Document:
             tupla ``(name (str), file (IOBase), mime_type (str))``
         :type document_file: tuple or list(tuple), optional
 
+        :param revocation_data: Dados para a revogação do documento. Vale notar
+            que em casos de atualização dos dados de revogação do documento, o
+            processamento não é reiniciado e o estado de revogação se mantém.
+        :type revocation_data: DocumentRevocationData, optional.
+
         :param update_description: Mensagem de atualização.
         :type update_description: str, optional
 
@@ -88,8 +96,12 @@ class Document:
         fields = {
             'documentType':
             str(document_type) if document_type is not None else None,
-            'documentData': document_data,
-            'updateDescription': update_description
+            'documentData':
+            document_data,
+            'revocationData':
+            revocation_data.as_json() if revocation_data is not None else None,
+            'updateDescription':
+            update_description
         }
         if document_file:
             fields['documentFile'] = document_file
@@ -622,6 +634,15 @@ class DocumentType:
     #: Representação visual. Equivalente a ``visual_rep_degree``.
     VISUAL_REP_DEGREE = 5
 
+    #: Lista de diplomas anulados. Equivalente a ``degree_revocation_list``.
+    DEGREE_REVOCATION_LIST = 8
+
+    #: Arquivo de fiscalização da IES registradora. Equivalente a ``audit_file_registry``.
+    AUDIT_FILE_REGISTRAR = 9
+
+    #: Arquivo de fiscalização da IES emissora. Equivalente a ``audit_file_issuer``.
+    AUDIT_FILE_ISSUER = 10
+
 
 class ExternalDocumentType:
     '''Enumeração dos possíveis tipos de um :class:`Document <Document>`.'''
@@ -648,3 +669,46 @@ class DocumentAuthorizationState:
     UNAUTHORIZED = 'unauthorized' #: Não-autorizado.
     AWAITING = 'awaiting' #: Aguardando.
     # yapf: enable
+
+
+class DocumentRevocationReason:
+    '''
+    Enumeração das possíveis justificativas para revogação de um documento.
+    '''
+    #: Erro de Fato.
+    ERRO_DE_FATO = "Erro de Fato"
+
+    #: Erro de Direito.
+    ERRO_DE_DIREITO = "Erro de Direito"
+
+    #: Decisão Judicial.
+    DECISAO_JUDICIAL = "Decisão Judicial"
+
+    #: Reemissão para Complemento de Informação.
+    REEMISSAO_PARA_COMPLEMENTO_DE_INFORMACAO = "Reemissão para Complemento de Informação"
+
+    #: Reemissão para Inclusão de Habilitação.
+    REEMISSAO_PARA_INCLUSAO_DE_HABILITACAO = "Reemissão para Inclusão de Habilitação"
+
+    #: Reemissão para Anotaçao de Registro.
+    REEMISSAO_PARA_ANOTACAO_DE_REGISTRO = "Reemissão para Anotaçao de Registro"
+
+
+class DocumentRevocationData:
+    '''Representa dados sobre a revogação de um documento.'''
+    def __init__(self, reason, notes=""):
+        '''
+        Inicializa um objeto contendo dados sobre a revogação de um documento.
+
+        :param reason: Justificativa da revogação.
+        :type reason: DocumentRevocationReason
+
+        :param notes: Observações adicionais sobre a revogação.
+        :type notes: str, optional
+        '''
+        self.reason = reason
+        self.notes = notes
+
+    def as_json(self):
+        '''Serializa os dados sobre a revogação, em formato JSON.'''
+        json_dumps({"reason": self.reason, "notes": self.notes})
